@@ -7,7 +7,7 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(spawn receive msg snd quit wt snd_wt listener open_node);
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Carp;
 use IO::Select;
@@ -238,6 +238,7 @@ sub receive(&) {
 	unless ($ipc_loop) {
 		$ipc_loop = 1;
 		ipc_loop();
+		$ipc_loop = 0;
 	}
 }
 
@@ -443,7 +444,6 @@ sub ipc_loop(;$$) {
 
 	}
 	$need_reset = 1;
-	$ipc_loop = 0;
 	$quit = 0;
 	return;
 }
@@ -881,11 +881,11 @@ Sometimes it is easier to use a module L<BGS> - Background execution of subrouti
 
 =head1 AUTHOR
 
-Nick Kostirya
+Nick Kostyria
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 by Nick Kostirya
+Copyright (C) 2009 by Nick Kostyria
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
