@@ -7,7 +7,7 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(spawn receive msg snd quit wt snd_wt listener open_node);
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use Carp;
 use EV;
@@ -79,7 +79,7 @@ sub snd($$;@) {
 }
 
 
-sub quit() { EV::unloop; $ipc_loop = 0 }
+sub quit() { EV::unloop }
 
 
 sub snd_wt($$;@) {
@@ -257,6 +257,7 @@ sub receive(&) {
 		$ipc_loop = 1;
 		w_event_cb_reg();
 		EV::loop;
+		$ipc_loop = 0;
 	}
 }
 
@@ -477,11 +478,11 @@ See description in L<IPC::MPS>.
 
 =head1 AUTHOR
 
-Nick Kostirya
+Nick Kostyria
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009 by Nick Kostirya
+Copyright (C) 2009 by Nick Kostyria
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
